@@ -4,9 +4,8 @@ use crate::{
     mode::Mode,
 };
 use swc_atoms::js_word;
-use swc_common::{Spanned, SyntaxContext};
+use swc_common::{util::take::Take, Spanned, SyntaxContext};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{undefined, ExprExt, Value};
 
 impl<M> Pure<'_, M>
