@@ -1,11 +1,14 @@
 use super::Pure;
-use crate::{compress::util::is_valid_identifier, util::deeply_contains_this_expr};
+use crate::{compress::util::is_valid_identifier, mode::Mode, util::deeply_contains_this_expr};
 use swc_atoms::js_word;
 use swc_common::SyntaxContext;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{prop_name_eq, ExprExt};
 
-impl Pure<'_> {
+impl<M> Pure<'_, M>
+where
+    M: Mode,
+{
     pub(super) fn optimize_property_of_member_expr(&mut self, e: &mut MemberExpr) {
         if !e.computed {
             return;
